==> openeclass-4.0.2.zip: openeclass-4.0.2/README.md <==
# The Open eClass Platform 4.0.2

http://www.openeclass.org/

The Open eClass platform (formerly known as GUnet eClass) is a complete Course
Management System, used to store and present educational materials. It is the
solution offered by the Greek Academic Network (GUnet) to support asynchronous
elearning services. Its goal is the incorporation and constructive use of the
Internet and web technologies in the teaching and learning process.

Distribution of the platform started on March 2003 and, since then, it has
been designed and developed by the GUnet Asychronous eLearning group as an
open source software (under the GNU GPL Licence). Many developers and users
have contributed a great amount of work and ideas and we would like to express
our gratitude to all of them for their support. A complete list of
contributors can be found in the CREDITS.txt file.

Installation of Open eClass requires a web server with support for PHP >= 8.1
and a database server (MySQL or MariaDB). You can find detailed installation
instructions as well as other manuals at the following address:

http://docs.openeclass.org/en/start

GUnet Asychronous e-Learning Group
February 2025


# Πλατφόρμα Open eClass 4.0.2

http://www.openeclass.org/

Η πλατφόρμα Open eClass (παλιότερη ονομασία: GUnet eClass) είναι ένα
ολοκληρωμένο Σύστημα Διαχείρισης Ηλεκτρονικών Μαθημάτων και αποτελεί την
πρόταση του Ακαδημαϊκού Διαδικτύου GUnet για την υποστήριξη της Υπηρεσίας
Ασύγχρονης Τηλεκπαίδευσης. Αναπτύχθηκε από την Ομάδα Ασύγχρονης Τηλεκπαίδευσης
του Ακαδημαϊκού Διαδικτύου, υποστηρίζεται κεντρικά από το GUnet και διανέμεται
ελεύθερα ως Λογισμικό Ανοικτού Κώδικα.

Η διάθεση της πλατφόρμας ξεκίνησε το Μάρτιο του 2003 και, στα χρόνια που
πέρασαν από τότε, χρησιμοποιείται με επιτυχία από το σύνολο σχεδόν των
Ακαδημαϊκών Ιδρυμάτων της χώρας καθώς κι από ένα πλήθος άλλων εκπαιδευτικών
οργανισμών, υποστηρίζοντας ενεργά τις δράσεις Ασύγχρονης Τηλεκπαίδευσης και
Κατάρτισης.

Στόχος της είναι η παροχή υποδομών εκπαίδευσης και κατάρτισης ανεξάρτητα
από τους περιοριστικούς παράγοντες του χώρου και του χρόνου της κλασσικής
διδασκαλίας, καθώς και η εισαγωγή των νέων τεχνολογιών στην εκπαιδευτική
διαδικασία. Για την επίτευξη του παραπάνω στόχου η πλατφόρμα eClass υποστηρίζει
την ηλεκτρονική οργάνωση, αποθήκευση και παρουσίαση του εκπαιδευτικού υλικού,
που προσφέρεται σήμερα στους εκπαιδευόμενους με παραδοσιακά μέσα (βιβλία,
σημειώσεις, κ.λπ.), σε ψηφιακή μορφή άμεσα προσβάσιμη από το Διαδίκτυο.

Η Ομάδα Ασύγχρονης Τηλεκπαίδευσης του GUnet θα ήθελε να ευχαριστήσει όλους
τους χρήστες της πλατφόρμας που με τη συμμετοχή, τα σχόλια και τις παρατηρήσεις
τους, συμβάλλουν διαρκώς στη περαιτέρω ανάπτυξη και βελτίωσή της. Η υποστήριξή
τους μας δίνει τη δύναμη να συνεχίσουμε την προσπάθεια.

Παράλληλα θα θέλαμε να ευχαριστούμε θερμά όλους αυτούς που συνέβαλλαν στην ανάπτυξη
και βελτίωση της πλατφόρμας. (Περισσότερες πληροφορίες στο αρχείο CREDITS.txt)

Για την εγκατάσταση της πλατφόρμας απαιτείται ένας εξυπηρετητής web με υποστήριξη
PHP >= 8.1 και μια βάση δεδομένων (MySQL ή MariaDB). Αναλυτικές οδηγίες εγκατάστασης
και άλλα εγχειρίδια της πλατφόρμας μπορούν να βρεθούν στη διεύθυνση:

http://docs.openeclass.org/el/start

Ομάδα Ασύγχρονης Τηλεκπαίδευσης GUnet
Φεβρουάριος 2025

==> openeclass-4.1.3.zip: openeclass-4.1.3/README.md <==
# The Open eClass Platform 4.1

http://www.openeclass.org/

The Open eClass platform (formerly known as GUnet eClass) is a complete Course
Management System, used to store and present educational materials. It is the
solution offered by the Greek Academic Network (GUnet) to support asynchronous
elearning services. Its goal is the incorporation and constructive use of the
Internet and web technologies in the teaching and learning process.

Distribution of the platform started on March 2003 and, since then, it has
been designed and developed by the GUnet Asychronous eLearning group as an
open source software (under the GNU GPL Licence). Many developers and users
have contributed a great amount of work and ideas and we would like to express
our gratitude to all of them for their support. A complete list of
contributors can be found in the CREDITS.txt file.

Installation of Open eClass requires a web server with support for PHP >= 8.1
and a database server (MySQL or MariaDB). You can find detailed installation
instructions as well as other manuals at the following address:

http://docs.openeclass.org/en/start

GUnet Asychronous e-Learning Group
May 2025


# Πλατφόρμα Open eClass 4.1

http://www.openeclass.org/

Η πλατφόρμα Open eClass (παλιότερη ονομασία: GUnet eClass) είναι ένα
ολοκληρωμένο Σύστημα Διαχείρισης Ηλεκτρονικών Μαθημάτων και αποτελεί την
πρόταση του Ακαδημαϊκού Διαδικτύου GUnet για την υποστήριξη της Υπηρεσίας
Ασύγχρονης Τηλεκπαίδευσης. Αναπτύχθηκε από την Ομάδα Ασύγχρονης Τηλεκπαίδευσης
του Ακαδημαϊκού Διαδικτύου, υποστηρίζεται κεντρικά από το GUnet και διανέμεται
ελεύθερα ως Λογισμικό Ανοικτού Κώδικα.

Η διάθεση της πλατφόρμας ξεκίνησε το Μάρτιο του 2003 και, στα χρόνια που
πέρασαν από τότε, χρησιμοποιείται με επιτυχία από το σύνολο σχεδόν των
Ακαδημαϊκών Ιδρυμάτων της χώρας καθώς κι από ένα πλήθος άλλων εκπαιδευτικών
οργανισμών, υποστηρίζοντας ενεργά τις δράσεις Ασύγχρονης Τηλεκπαίδευσης και
Κατάρτισης.

Στόχος της είναι η παροχή υποδομών εκπαίδευσης και κατάρτισης ανεξάρτητα
από τους περιοριστικούς παράγοντες του χώρου και του χρόνου της κλασσικής
διδασκαλίας, καθώς και η εισαγωγή των νέων τεχνολογιών στην εκπαιδευτική
διαδικασία. Για την επίτευξη του παραπάνω στόχου η πλατφόρμα eClass υποστηρίζει
την ηλεκτρονική οργάνωση, αποθήκευση και παρουσίαση του εκπαιδευτικού υλικού,
που προσφέρεται σήμερα στους εκπαιδευόμενους με παραδοσιακά μέσα (βιβλία,
σημειώσεις, κ.λπ.), σε ψηφιακή μορφή άμεσα προσβάσιμη από το Διαδίκτυο.

Η Ομάδα Ασύγχρονης Τηλεκπαίδευσης του GUnet θα ήθελε να ευχαριστήσει όλους
τους χρήστες της πλατφόρμας που με τη συμμετοχή, τα σχόλια και τις παρατηρήσεις
τους, συμβάλλουν διαρκώς στη περαιτέρω ανάπτυξη και βελτίωσή της. Η υποστήριξή
τους μας δίνει τη δύναμη να συνεχίσουμε την προσπάθεια.

Παράλληλα θα θέλαμε να ευχαριστούμε θερμά όλους αυτούς που συνέβαλλαν στην ανάπτυξη
και βελτίωση της πλατφόρμας. (Περισσότερες πληροφορίες στο αρχείο CREDITS.txt)

Για την εγκατάσταση της πλατφόρμας απαιτείται ένας εξυπηρετητής web με υποστήριξη
PHP >= 8.1 και μια βάση δεδομένων (MySQL ή MariaDB). Αναλυτικές οδηγίες εγκατάστασης
και άλλα εγχειρίδια της πλατφόρμας μπορούν να βρεθούν στη διεύθυνση:

http://docs.openeclass.org/el/start

Ομάδα Ασύγχρονης Τηλεκπαίδευσης GUnet
Μάιος 2025
